## pyvcloud Sample Program Directory

This directory contains sample programs that demonstrate use of pyvcloud. 
You can run programs individually or run all of them at once using the 
`run_examples.sh` script.  

To run all samples, follow the steps below. 

1. Copy vcd_connection.sample to vcd_connection and fill in connection data.
2. Execute the script as follows: `./run_examples.sh vcd_connection`

Important note! Samples need to run in this directory to ensure paths work
correctly.  Cd here before you run scripts. 
